[vlc-devel] commit: Fix typo ( Rémi Denis-Courmont )

git version control git at videolan.org
Sun Jun 8 17:39:22 CEST 2008


vlc | branch: master | Rémi Denis-Courmont <rdenis at simphalempin.com> | Sun Jun  8 17:52:43 2008 +0300| [2487f4b1224c3ae07686de96b376d14325922e84]

Fix typo

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=2487f4b1224c3ae07686de96b376d14325922e84
---

 src/network/tcp.c |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/network/tcp.c b/src/network/tcp.c
index 87bcdb2..8045563 100644
--- a/src/network/tcp.c
+++ b/src/network/tcp.c
@@ -58,7 +58,7 @@
 #   define ETIMEDOUT WSAETIMEDOUT
 #endif
 
-static int SocksNegociate( vlc_object_t *, int fd, int i_socks_version,
+static int SocksNegotiate( vlc_object_t *, int fd, int i_socks_version,
                            const char *psz_user, const char *psz_passwd );
 static int SocksHandshakeTCP( vlc_object_t *,
                               int fd, int i_socks_version,
@@ -334,11 +334,11 @@ int __net_Accept( vlc_object_t *p_this, int *pi_fd, mtime_t i_wait )
 
 
 /*****************************************************************************
- * SocksNegociate:
+ * SocksNegotiate:
  *****************************************************************************
  * Negociate authentication with a SOCKS server.
  *****************************************************************************/
-static int SocksNegociate( vlc_object_t *p_obj,
+static int SocksNegotiate( vlc_object_t *p_obj,
                            int fd, int i_socks_version,
                            const char *psz_socks_user,
                            const char *psz_socks_passwd )
@@ -350,7 +350,7 @@ static int SocksNegociate( vlc_object_t *p_obj,
     if( i_socks_version != 5 )
         return VLC_SUCCESS;
 
     /* We negociate authentication */
 
     if( ( psz_socks_user == NULL ) && ( psz_socks_passwd == NULL ) )
         b_auth = true;
@@ -442,7 +442,7 @@ static int SocksHandshakeTCP( vlc_object_t *p_obj,
     }
 
     if( i_socks_version == 5 &&
-        SocksNegociate( p_obj, fd, i_socks_version,
+        SocksNegotiate( p_obj, fd, i_socks_version,
                         psz_user, psz_passwd ) )
         return VLC_EGENERIC;
 
@@ -334,11 +334,11 @@ int __net_Accept( vlc_object_t *p_this, int *pi_fd, mtime_t i_wait )
  *****************************************************************************
- * Negociate authentication with a SOCKS server.
+ * Negotiate authentication with a SOCKS server.
  *****************************************************************************/
@@ -350,7 +350,7 @@ static int SocksNegociate( vlc_object_t *p_obj,
         return VLC_SUCCESS;
 
-    /* We negociate authentication */
+    /* We negotiate authentication */
 
     if( ( psz_socks_user == NULL ) && ( psz_socks_passwd == NULL ) )




More information about the vlc-devel mailing list